Corrected the module name in the GPL preamble
[OSXPackageBuilder.git] / common.sh
index 0131199..e6b615f 100755 (executable)
--- a/common.sh
+++ b/common.sh
@@ -28,7 +28,8 @@
 #                USA
 #
 # Modification : If you modify this file please consider whether your 
#                changes ought to be passed back to the macsetup module.
 #
 
 #========================================
@@ -147,3 +148,31 @@ case "${darwin_major_rel_num}" in
     ;;
 esac
 
+#
+# identify the directory containing Privoxy's source
+#
+cd ..
+DIRS_FOUND=0
+SOURCE_DIR=""
+if [ -d dist ]; then
+       DIRS_FOUND=1
+fi
+if [ -d current ]; then
+       DIRS_FOUND=$(( DIRS_FOUND + 10 ))
+fi
+case "${DIRS_FOUND}" in
+       # only 'current' found
+       10)
+               SOURCE_DIR="current"
+       ;;
+       # only 'dist' found
+       1)
+               SOURCE_DIR="dist"
+       ;;
+       # either both or neither found
+       11|0)
+               read -p 'Could not select the Privoxy source directory. Please supply the directory name: ' SOURCE_DIR
+       ;;
+esac
+cd OSXPackageBuilder
+echo "Using ../${SOURCE_DIR} as location of Privoxy source"
\ No newline at end of file
@@ -28,7 +28,8 @@
 #
 # Modification : If you modify this file please consider whether your 
-#                changes ought to be passed back to the macsetup module.
+#                changes ought to be passed back to the OSXPackageBuilder
+#                module.
 #
 